@@ -21,8 +21,14 @@ function test_bluer_ugv_help() {
         "@swallow debug" \
         "@swallow select_target" \
         \
+        "@swallow ultrasonic" \
+        "@swallow ultrasonic review" \
+        "@swallow ultrasonic test" \
+        \
         "@ugv" \
         \
+        "@ugv git" \
+        \
         "@ugv parts" \
         "@ugv parts adjust" \
         \
