@@ -1,9 +1,12 @@
+from typing import Any
+
+from bluer_algo.socket.classes import SocketComm, DEV_HOST
 from bluer_sbc.imager.camera import instance as camera
 from bluer_sbc.env import BLUER_SBC_ENV
 
 from bluer_ugv.swallow.session.classical.keyboard import ClassicalKeyboard
 from bluer_ugv.swallow.session.classical.leds import ClassicalLeds
-from bluer_ugv.swallow.session.classical.setpoint import ClassicalSetPoint
+from bluer_ugv.swallow.session.classical.setpoint.classes import ClassicalSetPoint
 from bluer_ugv.logger import logger
 
 
@@ -29,5 +32,9 @@ class ClassicalCamera:
     def cleanup(self):
         camera.close(log=True)
 
+    def send_debug_data(self, data: Any) -> bool:
+        socket = SocketComm.connect_to(DEV_HOST)
+        return socket.send_data(data)
+
     def update(self) -> bool:
         return True
